:orphan:

Explanations
============

Explanation of how the library works and why it works that way.

.. toctree::
    :caption: Explanations

    explanations/why-use-skeleton
    explanations/why-src
    explanations/why-pre-commit
    explanations/features
    explanations/decisions